@@ -1,12 +1,10 @@
-# coding: utf-8
-
 """
     some decorators
     ~~~~~~~~~~~~~~~
 
     from PyLucid decorators.
 
-    :copyleft: 2009-2018 by the django-tools team, see AUTHORS for more details.
+    :copyleft: 2009-2020 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
@@ -18,12 +16,11 @@ from functools import wraps
 
 from django.conf import settings
 from django.contrib import messages
-from django.contrib.auth.models import Permission
 from django.core.exceptions import PermissionDenied
-from django.http import HttpRequest, HttpResponse, HttpResponseRedirect
-from django.shortcuts import render_to_response
+from django.http import HttpRequest
+from django.shortcuts import render
 from django.template import RequestContext
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 def check_permissions(superuser_only, permissions=()):
@@ -48,7 +45,7 @@ def check_permissions(superuser_only, permissions=()):
         def _check_permissions(request, *args, **kwargs):
             user = request.user
 
-            if not user.is_authenticated():
+            if not user.is_authenticated:
                 # FIXME: HttpResponseRedirect to admin login?
                 msg = _("Permission denied for anonymous user. Please log in.")
                 if settings.DEBUG:  # Usefull??
@@ -56,10 +53,9 @@ def check_permissions(superuser_only, permissions=()):
                 raise PermissionDenied(msg)
 
             if not user.has_perms(permissions):
-                msg = "User %r has not all permissions: %r (existing permissions: %r)" % (
-                    user,
-                    permissions,
-                    user.get_all_permissions(),
+                msg = (
+                    f"User {user!r} has not all permissions: {permissions!r}"
+                    f" (existing permissions: {user.get_all_permissions()!r})"
                 )
                 if settings.DEBUG:  # Usefull??
                     warnings.warn(msg)
@@ -110,27 +106,29 @@ def render_to(template_name=None, debug=False, **response_kwargs):
 
             if not isinstance(context, dict):
                 if debug:
-                    msg = ("renter_to info: %s (template: %r)" " has not return a dict, has return: %r (%r)") % (
-                        function.__name__,
-                        template_name,
-                        type(context),
-                        function.__code__,
+                    msg = (
+                        f"renter_to info: {function.__name__}"
+                        f" (template: {template_name!r}) has not return a dict,"
+                        f" has return: {type(context)!r} ({function.__code__!r})"
                     )
                     messages.info(request, msg)
                 return context
 
             template_name2 = context.pop("template_name", template_name)
-            assert template_name2 != None, (
+            assert template_name2 is not None, (
                 "Template name must be passed as render_to parameter"
                 " or 'template_name' must be inserted into context!"
             )
 
-            response = render_to_response(
-                template_name2, context, context_instance=RequestContext(request), **response_kwargs
+            response = render(
+                template_name2, context, context=RequestContext(request), **response_kwargs
             )
 
             if debug:
-                messages.info(request, "render debug for %r (template: %r):" % (function.__name__, template_name2))
+                messages.info(
+                    request,
+                    f"render debug for {function.__name__!r} (template: {template_name2!r}):"
+                )
                 messages.info(request, "local view context:", context)
                 messages.info(request, "response:", response.content)
 
@@ -160,7 +158,7 @@ def display_admin_error(func):
         except Exception as err:
             traceback.print_exc(file=sys.stderr)
             if settings.DEBUG:
-                return "%s: %s" % (err.__class__.__name__, err)
+                return f"{err.__class__.__name__}: {err}"
             else:
                 raise
 
@@ -173,10 +171,10 @@ def warn_class_usage(message, category=DeprecationWarning):
     """
 
     def cls_wrapper(cls):
-        class Wrapped(cls, object):
+        class Wrapped(cls):
             def __init__(self, *args, **kwargs):
                 warnings.warn(message, category)
-                super(Wrapped, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
 
             def __new__(cls, *args, **kwargs):
                 warnings.warn(message, category)
