@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     sign separated
     ~~~~~~~~~~~~~~
@@ -12,15 +10,7 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
 
-
-if __name__ == "__main__":
-    # For doctest only
-    import os
-    os.environ["DJANGO_SETTINGS_MODULE"] = "django_tools.django_tools_tests.test_settings"
-
-from django.utils import six
 from django import forms
 from django.db import models
 
@@ -45,6 +35,7 @@ def _split(raw_value, separator, strip_items, skip_empty):
     values = tuple(values)
     return values
 
+
 def _join(value, separator):
     if value is None:
         value = ""
@@ -58,27 +49,27 @@ class SignSeparatedInput(forms.widgets.Input):
 
     def __init__(self, separator=",", *args, **kwargs):
         self.separator = separator
-        super(SignSeparatedInput, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def render(self, name, value, attrs=None):
         value = _join(value, self.separator)
-        return super(SignSeparatedInput, self).render(name, value, attrs)
+        return super().render(name, value, attrs)
 
 
 class SignSeparatedFormField(forms.CharField):
     """
-    >>> SignSeparatedFormField().clean(u"one, two")
-    (u'one', u'two')
+    >>> SignSeparatedFormField().clean("one, two")
+    ('one', 'two')
 
-    >>> SignSeparatedFormField().to_python(u"one , two, 3,4")
-    (u'one', u'two', u'3', u'4')
-    >>> SignSeparatedFormField(strip_items=False).clean(u"one , two, 3,4")
-    (u'one ', u' two', u' 3', u'4')
+    >>> SignSeparatedFormField().to_python("one , two, 3,4")
+    ('one', 'two', '3', '4')
+    >>> SignSeparatedFormField(strip_items=False).clean("one , two, 3,4")
+    ('one ', ' two', ' 3', '4')
 
-    >>> SignSeparatedFormField(separator=" ").clean(u"one  two 3")
-    (u'one', u'two', u'3')
-    >>> SignSeparatedFormField(separator=" ", skip_empty=False).clean(u"one  two 3")
-    (u'one', u'', u'two', u'3')
+    >>> SignSeparatedFormField(separator=" ").clean("one  two 3")
+    ('one', 'two', '3')
+    >>> SignSeparatedFormField(separator=" ", skip_empty=False).clean("one  two 3")
+    ('one', '', 'two', '3')
 
     >>> try:
     ...     SignSeparatedFormField().clean(None)
@@ -92,6 +83,7 @@ class SignSeparatedFormField(forms.CharField):
     ...     print(err.__class__.__name__, err)
     ValidationError ['This field is required.']
     """
+
     def __init__(self, separator=",", strip_items=True, skip_empty=True, *args, **kwargs):
         self.separator = separator
         self.strip_items = strip_items
@@ -99,7 +91,7 @@ class SignSeparatedFormField(forms.CharField):
 
         self.widget = SignSeparatedInput(separator)
 
-        super(SignSeparatedFormField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def to_python(self, value):
         values = _split(value, self.separator, self.strip_items, self.skip_empty)
@@ -121,8 +113,8 @@ class SignSeparatedModelField(models.TextField):
     >>> f = SignSeparatedModelField().formfield()
     >>> isinstance(f, SignSeparatedFormField)
     True
-    >>> f.clean(u"one , two, 3,4")
-    (u'one', u'two', u'3', u'4')
+    >>> f.clean("one , two, 3,4")
+    ('one', 'two', '3', '4')
 
     kwargs would be pass to the widget:
     >>> f = SignSeparatedModelField(separator="x", strip_items=False, skip_empty=False).formfield()
@@ -165,7 +157,7 @@ class SignSeparatedModelField(models.TextField):
         self.separator = separator
         self.strip_items = strip_items
         self.skip_empty = skip_empty
-        super(SignSeparatedModelField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def to_python(self, value):
         """
@@ -189,15 +181,4 @@ class SignSeparatedModelField(models.TextField):
 
         kwargs["widget"] = SignSeparatedInput
         kwargs["form_class"] = SignSeparatedFormField
-        return super(SignSeparatedModelField, self).formfield(**kwargs)
-
-
-
-if __name__ == "__main__":
-    # Run all unittest directly
-    import doctest
-    print(doctest.testmod(
-#        verbose=True
-        verbose=False,
-    ))
-    print("DocTest end.")
+        return super().formfield(**kwargs)
