@@ -1,6 +1,3 @@
-# coding:utf-8
-
-
 """
     url form/model field
     ~~~~~~~~~~~~~~~~~~~~
@@ -11,12 +8,10 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
 
 from django.db.models.fields import CharField as OriginModelCharField
 from django.forms.fields import CharField as OriginFormsCharField
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from django_tools.validators import URLValidator2
 
@@ -30,7 +25,7 @@ class URLFormField2(OriginFormsCharField):
 
     To allow only local domains, disallow scheme and netloc:
     >>> URLFormField2(allow_schemes=None, allow_netloc=False).clean("/path/?query#fragment")
-    u'/path/?query#fragment'
+    '/path/?query#fragment'
 
     >>> try:
     ...     URLFormField2(allow_schemes=None, allow_netloc=False).clean("http://domain.tld/path/?query#fragment")
@@ -40,11 +35,11 @@ class URLFormField2(OriginFormsCharField):
 
     **Note:** this is also a valid "local" path (more info in URLValidator2 DocString):
     >>> URLFormField2(allow_schemes=None, allow_netloc=False).clean("domain.tld/path/?query#fragment")
-    u'domain.tld/path/?query#fragment'
+    'domain.tld/path/?query#fragment'
 
 
     >>> URLFormField2(allow_schemes=("svn",)).clean("svn://domain.tld")
-    u'svn://domain.tld'
+    'svn://domain.tld'
 
     >>> try:
     ...     URLFormField2(allow_schemes=("http","ftp")).clean("svn://domain.tld")
@@ -58,10 +53,10 @@ class URLFormField2(OriginFormsCharField):
     }
 
     def __init__(self, max_length=None, min_length=None, verify_exists=False,
-            allow_schemes=("http", "https"), allow_all_schemes=False, allow_netloc=True,
-            allow_query=True, allow_fragment=True, *args, **kwargs):
+                 allow_schemes=("http", "https"), allow_all_schemes=False, allow_netloc=True,
+                 allow_query=True, allow_fragment=True, **kwargs):
 
-        super(URLFormField2, self).__init__(max_length, min_length, *args, **kwargs)
+        super().__init__(max_length=max_length, min_length=min_length, **kwargs)
 
         self.validators.append(
             URLValidator2(
@@ -71,7 +66,6 @@ class URLFormField2(OriginFormsCharField):
         )
 
 
-
 class URLModelField2(OriginModelCharField):
     """
     A flexible version of the original django model URLField ;)
@@ -82,8 +76,8 @@ class URLModelField2(OriginModelCharField):
     >>> f = URLModelField2(verify_exists=False).formfield()
     >>> isinstance(f, URLFormField2)
     True
-    >>> f.clean(u"http://www.domain.tld/path?query#fragment")
-    u'http://www.domain.tld/path?query#fragment'
+    >>> f.clean("http://www.domain.tld/path?query#fragment")
+    'http://www.domain.tld/path?query#fragment'
 
     >>> f = URLModelField2().formfield()
 
@@ -96,7 +90,7 @@ class URLModelField2(OriginModelCharField):
 
     >>> f = URLModelField2(allow_query=False).formfield()
     >>> f.clean("http://www.domain.tld/without/query/")
-    u'http://www.domain.tld/without/query/'
+    'http://www.domain.tld/without/query/'
 
     >>> try:
     ...     f.clean("http://www.domain.tld/with/?query")
@@ -108,8 +102,8 @@ class URLModelField2(OriginModelCharField):
     description = _("URL")
 
     def __init__(self, verbose_name=None, name=None, verify_exists=True,
-            allow_schemes=("http", "https"), allow_all_schemes=False, allow_netloc=True,
-            allow_query=True, allow_fragment=True, **kwargs):
+                 allow_schemes=("http", "https"), allow_all_schemes=False, allow_netloc=True,
+                 allow_query=True, allow_fragment=True, **kwargs):
 
         kwargs['max_length'] = kwargs.get('max_length', 200)
         OriginModelCharField.__init__(self, verbose_name, name, **kwargs)
@@ -132,12 +126,11 @@ class URLModelField2(OriginModelCharField):
         defaults = {
             'form_class': URLFormField2,
 
-            "allow_schemes":self.allow_schemes,
-            "allow_all_schemes":self.allow_all_schemes,
-            "allow_netloc":self.allow_netloc,
-            "allow_query":self.allow_query,
-            "allow_fragment":self.allow_fragment,
+            "allow_schemes": self.allow_schemes,
+            "allow_all_schemes": self.allow_all_schemes,
+            "allow_netloc": self.allow_netloc,
+            "allow_query": self.allow_query,
+            "allow_fragment": self.allow_fragment,
         }
         defaults.update(kwargs)
-        return super(URLModelField2, self).formfield(**defaults)
-
+        return super().formfield(**defaults)
