@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     exceptions for filemanager
     ~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -8,9 +6,6 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
-
 
 class FilemanagerError(Exception):
     """
@@ -24,4 +19,4 @@ class DirectoryTraversalAttack(FilemanagerError):
     """
     Some unauthorized signs are found or the path is out of the base path.
     """
-    pass
\ No newline at end of file
+    pass
