@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     mail util
     ~~~~~~~~~
@@ -8,19 +6,18 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
 from django.conf import settings
 from django.core.mail.message import EmailMultiAlternatives
 from django.template.loader import render_to_string
-from django.utils import six
+
 
 log = logging.getLogger(__name__)
 
 
-class SendMail(object):
+class SendMail:
     fail_silently = False
 
     def __init__(
@@ -51,8 +48,8 @@ class SendMail(object):
         self.mail_context = mail_context
         self.subject = subject
 
-        assert recipient_list, "No recipient given: %r" % recipient_list
-        if isinstance(recipient_list, six.string_types):
+        assert recipient_list, f"No recipient given: {recipient_list!r}"
+        if isinstance(recipient_list, str):
             self.recipient_list = [recipient_list]
         else:
             self.recipient_list = recipient_list
