@@ -25,11 +25,10 @@ class QueryLogMiddleware(MiddlewareMixin):
                 queries[sql] += 1
             duplicates = sum([count - 1 for count in list(queries.values())])
             print("------------------------------------------------------")
-            print("Total Queries:     %s" % len(queries))
-            print("Duplicate Queries: %s" % duplicates)
+            print(f"Total Queries:     {len(queries)}")
+            print(f"Duplicate Queries: {duplicates}")
             print()
             for query, count in list(queries.items()):
-                print("%s x %s" % (count, query))
+                print(f"{count} x {query}")
             print("------------------------------------------------------")
         return response
-
