@@ -1,6 +1,4 @@
-
-
-class DisableMigrations(object):
+class DisableMigrations:
     """
     Speedup test run start by disable migrations, just create the database tables ;)
 
@@ -9,8 +7,9 @@ class DisableMigrations(object):
     from django_tools.unittest_utils.disable_migrations import DisableMigrations
     MIGRATION_MODULES = DisableMigrations()
     """
+
     def __contains__(self, item):
         return True
 
     def __getitem__(self, item):
-        return "notmigrations"
\ No newline at end of file
+        return "notmigrations"
