@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     DjangoCommandMixin
     ~~~~~~~~~~~~~~~~~~
@@ -8,29 +6,29 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import unicode_literals, print_function
 
 import os
 import pprint
 import subprocess
-
 import sys
+from shlex import quote
 
 
-class DjangoCommandMixin(object):
-    def subprocess_getstatusoutput(self, cmd, debug=False, **kwargs):
+class DjangoCommandMixin:
+    def subprocess_getstatusoutput(self, cmd, debug=False, excepted_exit_code=0, **kwargs):
         """
         Return (status, output) of executing cmd in a shell.
 
         similar to subprocess.getstatusoutput but pass though kwargs
         """
+        assert isinstance(cmd, (list, tuple))
 
         # Assume that DJANGO_SETTINGS_MODULE not in environment
         # e.g:
         #   manage.py use os.environ.setdefault("DJANGO_SETTINGS_MODULE",...)
         #   so it will ignore the own module path!
         # You can set env by given kwargs, too.
-        env=dict(os.environ)
+        env = dict(os.environ)
         if "DJANGO_SETTINGS_MODULE" in env:
             del(env["DJANGO_SETTINGS_MODULE"])
 
@@ -43,11 +41,11 @@ class DjangoCommandMixin(object):
         subprocess_kwargs.update(kwargs)
         if "cwd" in subprocess_kwargs:
             cwd = subprocess_kwargs["cwd"]
-            assert os.path.isdir(cwd), "cwd %r doesn't exists!" % cwd
+            assert os.path.isdir(cwd), f"cwd {cwd!r} doesn't exists!"
             if debug:
-                print("DEBUG: cwd %r, ok" % cwd)
+                print(f"DEBUG: cwd {cwd!r}, ok")
 
-        cmd=" ".join(cmd) # FIXME: Why?!?
+        cmd = ' '.join(quote(arg) for arg in cmd)
         try:
             output = subprocess.check_output(cmd, **subprocess_kwargs)
             status = 0
@@ -55,12 +53,11 @@ class DjangoCommandMixin(object):
             output = ex.output
             status = ex.returncode
 
-        if output[-1:] == '\n':
-            output = output[:-1]
+        output = output.rstrip('\n\x1b[0m')
 
-        if status != 0 or debug:
+        if status != excepted_exit_code or debug:
             msg = (
-                "subprocess exist status == %(status)r\n"
+                "subprocess exist status == %(status)r (excepted: %(excepted_exit_code)r)\n"
                 "Call %(cmd)r with:\n"
                 "%(kwargs)s\n"
                 "subprocess output:\n"
@@ -69,11 +66,12 @@ class DjangoCommandMixin(object):
                 "------------------------------------------------------------\n"
             ) % {
                 "status": status,
+                "excepted_exit_code": excepted_exit_code,
                 "cmd": cmd,
                 "kwargs": pprint.pformat(subprocess_kwargs),
                 "output": output
             }
-            if status != 0:
+            if status != excepted_exit_code:
                 raise AssertionError(msg)
             else:
                 print(msg)
@@ -101,7 +99,6 @@ class DjangoCommandMixin(object):
         cmd = [sys.executable, manage_py] + list(cmd)
         kwargs.update({
             "cwd": manage_dir,
-            #"debug": True,
+            # "debug": True,
         })
         return self.subprocess_getstatusoutput(cmd, **kwargs)
-
