@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
     Mockups
     ~~~~~~~
@@ -8,9 +6,9 @@ import io
 import tempfile
 
 from django.core.files import File as DjangoFile
-
 from PIL import Image, ImageDraw, ImageFont
 
+
 try:
     from filer.models import Image as FilerImage
 except ImportError as err:
@@ -129,16 +127,17 @@ class ImageDummy:
         self.fill_image(image)
         return image
 
-    def create_info_image(self, text):
+    def create_info_image(self, text=None):
         """
         return a 'filled' PIL image with >text<
         """
         image = self.create_pil_image()
         draw = ImageDraw.Draw(image)
-        draw.multiline_text((10, 10), text, fill=self.text_color, align=self.text_align)
+        if text:
+            draw.multiline_text((10, 10), text, fill=self.text_color, align=self.text_align)
         return image
 
-    def create_django_file_info_image(self, text, filename=None):
+    def create_django_file_info_image(self, text=None, filename=None):
         """
         Create a django.core.files.base.File instance:
             1. fill a PIL image with a colorful gradient
@@ -147,7 +146,7 @@ class ImageDummy:
         usable to attach this to: models.ImageField()
         """
         if filename is None:
-            filename = "dummy.%s" % self.format.lower()
+            filename = f"dummy.{self.format.lower()}"
 
         pil_image = self.create_info_image(text)
 
@@ -167,7 +166,7 @@ class ImageDummy:
             # Django-Filer is not available: raise the origin error
             raise ImportError(FILER_IMPORT_ERROR)
 
-        f = tempfile.NamedTemporaryFile(prefix=self.temp_prefix, suffix=".%s" % self.format)
+        f = tempfile.NamedTemporaryFile(prefix=self.temp_prefix, suffix=f".{self.format}")
         image = self.create_info_image(text)
         image.save(f, format=self.format)
         filer_image = create_filer_image(f, user)
