@@ -1,11 +1,8 @@
-# coding:utf-8
-
 """
     :copyleft: 2017 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import unicode_literals, absolute_import, print_function
 
 from django.conf import settings
 from django.contrib.auth.models import AnonymousUser
