@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# coding: utf-8
 
 """
     stack information
@@ -9,15 +8,12 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-from __future__ import absolute_import, division, print_function
-
-
 
 import inspect
 
 
-STACK_LIMIT = 6 # Display only the last X stack lines
-MAX_FILEPATH_LEN = 50 # Cut filepath in stack info message
+STACK_LIMIT = 6  # Display only the last X stack lines
+MAX_FILEPATH_LEN = 50  # Cut filepath in stack info message
 
 
 def format_list(extracted_list):
@@ -25,7 +21,7 @@ def format_list(extracted_list):
     Format a list of traceback entry tuples.
     """
     list = []
-    for _, filename, lineno, func_name, line, _  in extracted_list:
+    for _, filename, lineno, func_name, line, _ in extracted_list:
         code = "".join(line).strip()
         item = (
             'File "%s", line %d, in %s\n'
